Skip to contents

texture_polygon_sources() returns metadata for texture polygon datasets that may be added in future phases from original official or academic sources. It does not include polygon coordinates or class vertex tables.

Usage

texture_polygon_sources()

Value

A tibble describing planned texture polygon sources.