gs_folk_ward() calculates Folk and Ward graphical statistics from
boundary-interpolated grain-size percentiles. Percentiles follow the package
convention where D_p is the grain size at which p percent of the sample
is finer.
Usage
gs_folk_ward(
x,
interpolation_scale = "phi",
extrapolate = c("error", "warn_linear"),
include_descriptions = TRUE
)Arguments
- x
A valid
gsd_tblobject.- interpolation_scale
Interpolation scale passed to
gs_d_values().- extrapolate
Extrapolation behavior passed to
gs_d_values().- include_descriptions
Should descriptive Folk and Ward class labels be included?
Details
The underlying D_p percentiles are computed by gs_d_values(),
including its deterministic tie-breaking rule for percentiles that fall
on a plateau caused by consecutive zero-retained classes (see
gs_d_values() for details).